<?php
// Reset an array's indicies and remove empty values
function array_reset($array) {
	$new_array = array();
	$i = 0;
	foreach ($array as $a) {
		if (strlen($a)) {
			$new_array[$i++] = $a;
		}
	}
	return $new_array;
}

// Format a query string to be processed by the OCI library
function format_query_array($query) {
	$extended_queries = array(
		"CREATE TRIGGER",
		"CREATE OR REPLACE TRIGGER"
	);
	
	// Remove the / mark from extended queries, as it is unnecessary
	for ($x = 0; $x < sizeof($query); $x++) {
		if (substr(trim($query[$x]), 0, 1) == "/" && substr(trim($query[$x]), 1, 1) != "*") {
			$query[$x] = substr(trim($query[$x]), 1);
		}
	}

	// Look for any extended queries, and build them into a single query
	for ($x = 0; $x < sizeof($query); $x++) {		
		for ($y = 0; $y < sizeof($extended_queries); $y++) {
			$check_line = strtoupper(trim(alter_comments($query[$x], true)));
			if (strpos($check_line, $extended_queries[$y]) === 0) {
				$i = $x;
				while (strtoupper(trim(alter_comments($query[$x], true))) != "END" && $x < sizeof($query)-1) {
					$query[$i] .= "; ".$query[$x+1];
					$x++;
				}
				$query[$i] .= ";";
				
				for ($z = $i+1; $z <= $x; $z++) {
					$query[$z] = "";
				}				
			}
		}
	}

	return array_reset($query);
}

// Get the current page's script path
function get_page_path() {
	$path = explode("/", $_SERVER["SCRIPT_NAME"]);
	$path[sizeof($path)-1] = "";
	return implode("/", $path);
}

// Perform a oracle_query - shorthand for the typical OCI selection process
function oracle_query($sql) {
	global $DB_CONNECTION;
	
	$query = oci_parse($DB_CONNECTION, $sql);
	if ($query) {
		oci_execute($query);
	}
	
	return $query;
}

// Convert comments from -- to /* */ because they parse better. 
// Can also be called to remove comments entirely.
function alter_comments($query, $remove = false) {
	$query = explode("\n", $query);
	
	for ($x = 0; $x < sizeof($query); $x++) {
		if (substr_count($query[$x], "--")) {
			$dash_pos = strpos($query[$x], "--");
			$query[$x] = substr_replace($query[$x], "/*".substr($query[$x], $dash_pos+2)." */", $dash_pos);
		}
	}

	$query = array_reset($query);
	$query = implode("\n", $query);
	
	if ($remove) {
		$query = preg_replace('!/\*(.*?)\*/!s', '', $query);
	}
	
	return $query;
}

// Run an array of user queries, and return any errors
function run_query_array($query) {
	global $DB_CONNECTION;
	
	for ($x = 0; $x < sizeof($query); $x++) {
		$query[$x] = str_replace(array("\r", "\n"), " ", $query[$x]);
		$parse[$x] = oci_parse($DB_CONNECTION, $query[$x]);
		$error[$x] = oci_error($DB_CONNECTION);
		if ($error[$x]) {
			return array($error, 1);
		}
	}

	for ($x = 0; $x < sizeof($query); $x++) {
		oci_execute($parse[$x]);
		$error[$x] = oci_error($parse[$x]);
		if ($error[$x]) {
			return array($error, 0);
		}
	}
	
	return array($error, 0);
}

// Defines a list of "special" queries for user accessibility - will be expanded upon later
function special_query(&$table, &$sql) {
	if (isset($_GET["special"])) {
		if ($_GET["special"] == 1) {
			$table = "user_triggers";
			$sql = "SELECT * FROM $table";
		}
		if ($_GET["special"] == 2) {
			$table = "user_sequences";
			$sql = "SELECT * FROM $table";
		}
	}
}

function version_check() {
	$version = "2.1";
	
	$version_check = @file_get_contents("http://fitzpatrickdev.com/oracle_dbms/version.txt");
	if ($version_check) {
		$current_version = substr($version_check, 0, 3);
		$text = substr($version_check, 3);
		
		if ($version != $current_version) {
			echo '<div style="background-color:rgba(200,0,0,.1);padding:5px;border:2px solid #800;">';
			echo '<div style="font-weight:bold;font-style:italic;">Alert:</div>';
			echo str_replace("\n", "<br>", htmlspecialchars(trim($text)));
			echo '<br><br>';
			echo '<a href="http://fitzpatrickdev.com/oracle_dbms/oracle_dbms.zip" target="_blank">Click here to download the latest version of Oracle DBMS lite.</a>';
			echo '</div>';
			echo '<br><br>';
		}
	}
}
?>