<?php
require 'header.php';

// Check for a special query
special_query($table, $sql);

// Process a user command
if (isset($_POST["query"])) {
	$command = trim($_POST["query"]);
	$query = alter_comments($command);
		
	if (substr($query, -1) == ";") {
		$query = substr($query, 0, -1);
	}

	$query = explode(";", $query);
	$parse[0] = oci_parse($DB_CONNECTION, $query[0]);
	
	// Perform a select query if the user inputs a single select query
	if (sizeof($query) == 1 && oci_statement_type($parse[0]) == "SELECT") {
		$error[0] = oci_error($DB_CONNECTION);
		if (!$error[0]) {
			oci_execute($parse[0]);
			$error[0] = oci_error($parse[0]);
			if (!$error[0]) {
				$sql = $query[0];
				preg_match("/ FROM ([^\s]+)/i", $sql, $matches);
				$table = $matches[1];
			}
		}
	}
	// Else, process a batch query
	else {
		$query = format_query_array($query);
		$error_array = run_query_array($query);
		$error = $error_array[0];
		$no_executions = $error_array[1];
	}
}

// Set the table if one is not already specified
if (!$table) {
	$table = preg_replace("/[^A-Za-z0-9_]/", "", $_REQUEST["table"]);
	$sql = "SELECT * FROM $table";
	if (!$command && $table) {
		$command = $sql;
	}
}

// Run the select query for the view display
if ($table) {
	$result = oracle_query($sql);
	
	while ($row = oci_fetch_assoc($result)) {
		$rows[] = $row;
	}
	
	// Get information on the columns and their data types
	$result = oracle_query("SELECT * FROM all_tab_columns WHERE LOWER(table_name)=LOWER('$table')");
	while ($row = oci_fetch_assoc($result)) {
		$new_column_data[0] = $row['COLUMN_NAME'];
		if ($row['CHAR_LENGTH']) {
			$new_column_data[1] = $row['DATA_TYPE'].'('.$row['CHAR_LENGTH'].')';
		}
		else if ($row['DATA_PRECISION']) {
			$new_column_data[1] = $row['DATA_TYPE'].'('.$row['DATA_PRECISION'].')';
		}
		else {
			$new_column_data[1] = $row['DATA_TYPE'];
		}
		$column_data[] = $new_column_data;
	}
	
	// If user narrows the selected columns, handle that condition properly
	if (sizeof($rows)) {
		$copy_column_data = $column_data;
		unset($column_data);
		$selected_cols = array_keys($rows[0]);
		for ($x = 0; $x < sizeof($selected_cols); $x++) {
			$column_data[$x][0] = $selected_cols[$x];
			for ($y = 0; $y < sizeof($copy_column_data); $y++) {
				if ($selected_cols[$x] == $copy_column_data[$y][0]) {
					$column_data[$x][1] = $copy_column_data[$y][1];
				}
			}
		}
	}
}
?>
<?php if ($table) { ?>
<div style="text-align: center;margin-top:30px;">
	<h2><a href="query.php?table=<?php echo $table; ?>"><?php echo $table; ?></a></h2>
</div>
<?php } else { ?>
<div style="text-align:center;">
	<h2 style="color:#00A;">Oracle DBMS lite</h2>
</div>
<?php } ?>
<?php
// Cycle through the user input commands
for ($x = 0; $x < sizeof($query); $x++) {
	// If an error is detected, display the red error box
	if ($error[$x]) {	
		echo '<div style="width:100%;">';
		echo '<div style="background-color:rgba(200,0,0,.1);border:2px solid #800;padding:5px;overflow:auto;">';
		echo '<span style="font-weight:bold;font-style:italic;">Command failed:</span>';
		echo '<br>'.str_replace(array("\n", " ", "\t"), array("<br>", "&nbsp;", "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"), htmlspecialchars(trim($query[$x])));
		echo '<br><br>';
		echo '<div style="font-weight:bold;">'.htmlspecialchars($error[$x]['message']);
		if ($error[$x]['offset']) {
			echo ' near:</div><br> '.htmlspecialchars(substr($error[$x]['sqltext'], $error[$x]['offset'], 20));
		}
		else {
			echo '</div>';
		}
		echo '</div>';
		echo '</div>';
		break;
	}
	// Else, display the green confirmation box
	else {
		echo '<div style="width:100%;">';
		if ($no_executions) {
			echo '<div style="background-color:rgba(255,255,0,.1);border:2px solid #080;padding:5px;overflow:auto;">';
			echo '<span style="font-weight:bold;font-style:italic;">Command parsed successfully, but not executed due to later errors:</span>';
		}
		else {
			echo '<div style="background-color:rgba(0,200,0,.1);border:2px solid #080;padding:5px;overflow:auto;">';
			echo '<span style="font-weight:bold;font-style:italic;">Command executed successfully:</span>';
		}
		echo '<br>'.str_replace(array("\n", " ", "\t"), array("<br>", "&nbsp;", "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"), htmlspecialchars(trim($query[$x])));
	
		echo '</div>';
		echo '</div>';
	}
}
?>
<div style="font-weight:bold;">Query window:</div>
<form action="query.php" method="post" id="query_form">
	<textarea name="query" id="query_window" style="width:99%;height:40px;" onFocus="javascript:this.style.height='150px';"><?php echo $command; ?></textarea>
	<input type="hidden" name="table" value="<?php echo $table; ?>">
	<input type="submit" value="Submit Query" style="float:right;">
</form>
<?php if ($table) { ?>
<br><b>Query:</b> <?php echo htmlspecialchars($sql); ?>
<br><b>Selected rows:</b> <?php echo sizeof($rows);?>
<hr>
<table style="margin:0px auto;">
	<tr>
	<?php 
	// Print the table header columns and their data types via a mouseover
	for ($x = 0; $x < sizeof($column_data); $x++) {
		echo '<th>';
		if ($column_data[$x][1]) {
			echo '<span style="border-bottom:1px dotted #000;cursor:help;" title="'.$column_data[$x][1].'">'.$column_data[$x][0].'</span>';
		}
		else {
			echo $column_data[$x][0];
		}		
		echo '</th>';
	}
	?>
	</tr>
	<?php
		// Print the table data
		foreach ($rows as $row) {
			echo '<tr>';
			foreach ($row as $r) {
				$cell_counter++;
				echo '<td>';
				if (strlen($r) > 20) {
					echo htmlspecialchars(substr($r, 0, 20)).'<a href="javascript:void(0)" onClick="toggle(\'cell['.$cell_counter.']\', true);this.style.display=\'none\';" style="cursor:pointer;">...</a><span id="cell['.$cell_counter.']" style="display:none;">'.htmlspecialchars(substr($r, 20)).'</span>';
				}
				else {
					echo htmlspecialchars($r);
				}
				echo '</td>';
			}
			echo '</tr>';
		}
	?>
</table>
<?php } else { ?>
<br style="clear:both;">
<table class="table_list">
	<tr>
		<th><span style="font-size:20pt;text-decoration:underline">Oracle Tables</span></th>
	</tr>
	<?php
	$result = oracle_query("SELECT table_name FROM tabs");
	while ($row = oci_fetch_assoc($result)) {
		echo '<tr><td><a href="query.php?table='.$row['TABLE_NAME'].'">'.$row['TABLE_NAME'].'</a></td></tr>';
	}
	?>
</table>
<?php } ?>
<?php
require 'footer.php';
?>